@@ -23,8 +23,7 @@ from .plotting import draw_points, draw_vectors, draw_lines, draw_surfaces
 __all__ = [
     "distance", "distances", "interweave", "vindices", "vrange", "cell_size",
     "cell_volume", "compute_vectors", "KDTree", "VoronoiTree",
-    "WignerSeitzCell", "rx", "ry", "rz", "rotate2d", "rotate3d",
-    "build_periodic_translation_vector", "periodic_translation_vectors"
+    "WignerSeitzCell", "rx", "ry", "rz", "rotate2d", "rotate3d"
 ]
 
 
@@ -299,8 +298,8 @@ def compute_vectors(a: float, b: float = None, c: float = None,
 class KDTree(scipy.spatial.cKDTree):
     """Simple wrapper of scipy's cKTree with global query settings."""
 
-    def __init__(self, points, k=1, max_dist=np.inf, eps=0., p=2):
-        super().__init__(points)
+    def __init__(self, points, k=1, max_dist=np.inf, eps=0., p=2, boxsize=None):
+        super().__init__(points, boxsize=boxsize)
         self.max_dist = max_dist
         self.k = k
         self.p = p
@@ -349,32 +348,6 @@ class KDTree(scipy.spatial.cKDTree):
         return neighbors, dists
 
 
-def build_periodic_translation_vector(indices, axs):
-    limits = np.array([np.min(indices, axis=0), np.max(indices, axis=0)])
-    idx_size = (limits[1] - limits[0])[:-1]
-    nvec = np.zeros_like(idx_size, dtype=np.int64)
-    for ax in np.atleast_1d(axs):
-        nvec[ax] = np.floor(idx_size[ax]) + 1
-    return nvec
-
-
-def periodic_translation_vectors(indices, axs):
-    # One axis: No combinations needed
-    if isinstance(axs, int) or len(axs) == 1:
-        return [(axs, build_periodic_translation_vector(indices, axs))]
-    # Add all combinations of the periodic axis
-    items = list()
-    for ax in itertools.combinations_with_replacement(axs, r=2):
-        nvec = build_periodic_translation_vector(indices, ax)
-        items.append((ax, nvec))
-        # Use +/- for every axis exept the first one to ensure all corners are hit
-        if not np.all(np.array(ax) == axs[0]):
-            nvec2 = np.copy(nvec)
-            nvec2[1:] *= -1
-            items.append((ax, nvec2))
-    return items
-
-
 class VoronoiTree:
 
     def __init__(self, points):
